﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using JYAG.ControlModel.UI.View;
using JYAG.ControlModel.UI.Task;

namespace JYAG.ControlModel.UI.Presenter
{
    public class LoginPresenter
    {
        private ILoginView view;
        private ILoginTask task;

        public LoginPresenter(ILoginView view, ILoginTask task)
        {
            this.view = view;
            this.task = task;
            view.InitializePresenter += (sender, e) => this.Initialize();
            HookUpEvents();
        }

        public LoginPresenter(ILoginView view) :
            this(view, new DummyLoginTask())
        {
        }

        private void Initialize()
        {
            this.view.RememberUserCheckBox.Checked = true;
            this.view.PasswordTextBox.IsPassword = true;
        }

        private void HookUpEvents()
        {
            this.view.LogInButton.Click += Login;
        }

        private void Login(object sender, EventArgs e)
        {
            this.view.ErrorMessageLabel.Visible = false;
            string username = this.view.UsernameTextBox.Text;
            string password = this.view.PasswordTextBox.Text;

            try
            {
                bool succes = this.task.Login(username, password);
                if (succes == false)
                {
                    ShowErrorMessage("Login failed"); 
                }
            }
            catch (Exception ex)
            {
                ShowErrorMessage(ex.Message); 
            }
        }

        private void ShowErrorMessage(string message)
        {
            this.view.ErrorMessageLabel.Text = message;
            this.view.ErrorMessageLabel.Visible = true;
        }
    }
}
